# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFFTPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFFTWInverseFFTImageFilterPython
else:
    import _itkFFTWInverseFFTImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkInverseFFTImageFilterPython
import itk.itkImageToImageFilterBPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkFFTWInverseFFTImageFilterICF2IF2_New():
    return itkFFTWInverseFFTImageFilterICF2IF2.New()

class itkFFTWInverseFFTImageFilterICF2IF2(itk.itkInverseFFTImageFilterPython.itkInverseFFTImageFilterICF2IF2):
    r"""Proxy of C++ itkFFTWInverseFFTImageFilterICF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFFTWInverseFFTImageFilterICF2IF2_Pointer"""
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFFTWInverseFFTImageFilterICF2IF2_Pointer"""
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF2IF2_Clone(self)

    def GetPlanRigor(self):
        r"""GetPlanRigor(self) -> int const &"""
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF2IF2_GetPlanRigor(self)

    def SetPlanRigor(self, *args):
        r"""
        SetPlanRigor(self, value)

        Parameters
        ----------
        value: int const &

        SetPlanRigor(self, name)

        Parameters
        ----------
        name: std::string const &

        """
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF2IF2_SetPlanRigor(self, *args)
    __swig_destroy__ = _itkFFTWInverseFFTImageFilterPython.delete_itkFFTWInverseFFTImageFilterICF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFFTWInverseFFTImageFilterICF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFFTWInverseFFTImageFilterICF2IF2

        Create a new object of the class itkFFTWInverseFFTImageFilterICF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFFTWInverseFFTImageFilterICF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFFTWInverseFFTImageFilterICF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFFTWInverseFFTImageFilterICF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFFTWInverseFFTImageFilterICF2IF2 in _itkFFTWInverseFFTImageFilterPython:
_itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF2IF2_swigregister(itkFFTWInverseFFTImageFilterICF2IF2)

def itkFFTWInverseFFTImageFilterICF3IF3_New():
    return itkFFTWInverseFFTImageFilterICF3IF3.New()

class itkFFTWInverseFFTImageFilterICF3IF3(itk.itkInverseFFTImageFilterPython.itkInverseFFTImageFilterICF3IF3):
    r"""Proxy of C++ itkFFTWInverseFFTImageFilterICF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFFTWInverseFFTImageFilterICF3IF3_Pointer"""
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFFTWInverseFFTImageFilterICF3IF3_Pointer"""
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF3IF3_Clone(self)

    def GetPlanRigor(self):
        r"""GetPlanRigor(self) -> int const &"""
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF3IF3_GetPlanRigor(self)

    def SetPlanRigor(self, *args):
        r"""
        SetPlanRigor(self, value)

        Parameters
        ----------
        value: int const &

        SetPlanRigor(self, name)

        Parameters
        ----------
        name: std::string const &

        """
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF3IF3_SetPlanRigor(self, *args)
    __swig_destroy__ = _itkFFTWInverseFFTImageFilterPython.delete_itkFFTWInverseFFTImageFilterICF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFFTWInverseFFTImageFilterICF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFFTWInverseFFTImageFilterICF3IF3

        Create a new object of the class itkFFTWInverseFFTImageFilterICF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFFTWInverseFFTImageFilterICF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFFTWInverseFFTImageFilterICF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFFTWInverseFFTImageFilterICF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFFTWInverseFFTImageFilterICF3IF3 in _itkFFTWInverseFFTImageFilterPython:
_itkFFTWInverseFFTImageFilterPython.itkFFTWInverseFFTImageFilterICF3IF3_swigregister(itkFFTWInverseFFTImageFilterICF3IF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def fftw_inverse_fft_image_filter(*args: itkt.ImageLike,  plan_rigor: Union[int, str]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for FFTWInverseFFTImageFilter"""
    import itk

    kwarg_typehints = { 'plan_rigor':plan_rigor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.FFTWInverseFFTImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def fftw_inverse_fft_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKFFT.FFTWInverseFFTImageFilter
    fftw_inverse_fft_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    fftw_inverse_fft_image_filter.__doc__ = filter_object.__doc__



